package SDL::ConfigData;
use strict;
my $arrayref = eval do {local $/; <DATA>}
  or die "Couldn't load ConfigData data: $@";
close DATA;
my ($config, $features, $auto_features) = @$arrayref;

sub config { $config->{$_[1]} }

sub set_config { $config->{$_[1]} = $_[2] }
sub set_feature { $features->{$_[1]} = 0+!!$_[2] }  # Constrain to 1 or 0

sub auto_feature_names { grep !exists $features->{$_}, keys %$auto_features }

sub feature_names {
  my @features = (keys %$features, auto_feature_names());
  @features;
}

sub config_names  { keys %$config }

sub write {
  my $me = __FILE__;
  require IO::File;

  # Can't use Module::Build::Dumper here because M::B is only a
  # build-time prereq of this module
  require Data::Dumper;

  my $mode_orig = (stat $me)[2] & 07777;
  chmod($mode_orig | 0222, $me); # Make it writeable
  my $fh = IO::File->new($me, 'r+') or die "Can't rewrite $me: $!";
  seek($fh, 0, 0);
  while (<$fh>) {
    last if /^__DATA__$/;
  }
  die "Couldn't find __DATA__ token in $me" if eof($fh);

  seek($fh, tell($fh), 0);
  my $data = [$config, $features, $auto_features];
  $fh->print( 'do{ my '
	      . Data::Dumper->new([$data],['x'])->Purity(1)->Dump()
	      . '$x; }' );
  truncate($fh, tell($fh));
  $fh->close;

  chmod($mode_orig, $me)
    or warn "Couldn't restore permissions on $me: $!";
}

sub feature {
  my ($package, $key) = @_;
  return $features->{$key} if exists $features->{$key};

  my $info = $auto_features->{$key} or return 0;

  # Under perl 5.005, each(%$foo) isn't working correctly when $foo
  # was reanimated with Data::Dumper and eval().  Not sure why, but
  # copying to a new hash seems to solve it.
  my %info = %$info;

  require Module::Build;  # XXX should get rid of this
  while (my ($type, $prereqs) = each %info) {
    next if $type eq 'description' || $type eq 'recommends';

    my %p = %$prereqs;  # Ditto here.
    while (my ($modname, $spec) = each %p) {
      my $status = Module::Build->check_installed_status($modname, $spec);
      if ((!$status->{ok}) xor ($type =~ /conflicts$/)) { return 0; }
      if ( ! eval "require $modname; 1" ) { return 0; }
    }
  }
  return 1;
}


=head1 NAME

SDL::ConfigData - Configuration for SDL

=head1 SYNOPSIS

  use SDL::ConfigData;
  $value = SDL::ConfigData->config('foo');
  $value = SDL::ConfigData->feature('bar');

  @names = SDL::ConfigData->config_names;
  @names = SDL::ConfigData->feature_names;

  SDL::ConfigData->set_config(foo => $new_value);
  SDL::ConfigData->set_feature(bar => $new_value);
  SDL::ConfigData->write;  # Save changes


=head1 DESCRIPTION

This module holds the configuration data for the C<SDL>
module.  It also provides a programmatic interface for getting or
setting that configuration data.  Note that in order to actually make
changes, you'll have to have write access to the C<SDL::ConfigData>
module, and you should attempt to understand the repercussions of your
actions.


=head1 METHODS

=over 4

=item config($name)

Given a string argument, returns the value of the configuration item
by that name, or C<undef> if no such item exists.

=item feature($name)

Given a string argument, returns the value of the feature by that
name, or C<undef> if no such feature exists.

=item set_config($name, $value)

Sets the configuration item with the given name to the given value.
The value may be any Perl scalar that will serialize correctly using
C<Data::Dumper>.  This includes references, objects (usually), and
complex data structures.  It probably does not include transient
things like filehandles or sockets.

=item set_feature($name, $value)

Sets the feature with the given name to the given boolean value.  The
value will be converted to 0 or 1 automatically.

=item config_names()

Returns a list of all the names of config items currently defined in
C<SDL::ConfigData>, or in scalar context the number of items.

=item feature_names()

Returns a list of all the names of features currently defined in
C<SDL::ConfigData>, or in scalar context the number of features.

=item auto_feature_names()

Returns a list of all the names of features whose availability is
dynamically determined, or in scalar context the number of such
features.  Does not include such features that have later been set to
a fixed value.

=item write()

Commits any changes from C<set_config()> and C<set_feature()> to disk.
Requires write access to the C<SDL::ConfigData> module.

=back


=head1 AUTHOR

C<SDL::ConfigData> was automatically created using C<Module::Build>.
C<Module::Build> was written by Ken Williams, but he holds no
authorship claim or copyright claim to the contents of C<SDL::ConfigData>.

=cut


__DATA__
do{ my $x = [
  {
    'SDL_lib_translate' => {
      'SDL::CDTrack' => [
        'SDL'
      ],
      'SDL::CD' => [
        'SDL'
      ],
      'SDL::TTF' => [
        'SDL',
        'SDL_ttf'
      ],
      'SDL::GFX::Rotozoom' => [
        'SDL',
        'SDL_gfx'
      ],
      'SDL::Mixer::Effects' => [
        'SDL',
        'SDL_mixer'
      ],
      'SDLx::SFont' => [
        'SDL',
        'SDL_image'
      ],
      'SDL::Video' => [
        'SDL'
      ],
      'SDL::GFX::FPSManager' => [
        'SDL',
        'SDL_gfx'
      ],
      'SDL::CDROM' => [
        'SDL'
      ],
      'SDL::Palette' => [
        'SDL'
      ],
      'SDLx::Layer' => [
        'SDL',
        'SDL_image'
      ],
      'SDL::Pango::Context' => [
        'SDL',
        'SDL_Pango'
      ],
      'SDL::PixelFormat' => [
        'SDL'
      ],
      'SDLx::LayerManager' => [
        'SDL'
      ],
      'SDL::Surface' => [
        'SDL'
      ],
      'SDL::TTF::Font' => [
        'SDL',
        'SDL_ttf'
      ],
      'SDL::AudioCVT' => [
        'SDL'
      ],
      'SDL::Color' => [
        'SDL'
      ],
      'SDL::GFX::Framerate' => [
        'SDL',
        'SDL_gfx'
      ],
      'SDL::Mixer::MixChunk' => [
        'SDL',
        'SDL_mixer'
      ],
      'SDL::GFX' => [
        'SDL',
        'SDL_gfx'
      ],
      'SDL::MultiThread' => [
        'SDL'
      ],
      'SDL::GFX::ImageFilter' => [
        'SDL',
        'SDL_gfx'
      ],
      'SDL::GFX::Primitives' => [
        'SDL',
        'SDL_gfx'
      ],
      'SDL::Overlay' => [
        'SDL'
      ],
      'SDL::VideoInfo' => [
        'SDL'
      ],
      'SDL_perl' => [
        'SDL'
      ],
      'SDL::Cursor' => [
        'SDL'
      ],
      'SDL::Pango' => [
        'SDL',
        'SDL_Pango'
      ],
      'SDL::Mouse' => [
        'SDL'
      ],
      'SDL::Rect' => [
        'SDL'
      ],
      'SDL::Mixer::Samples' => [
        'SDL',
        'SDL_mixer'
      ],
      'SDL::Events' => [
        'SDL'
      ],
      'SDL::Audio' => [
        'SDL'
      ],
      'SDL::Mixer' => [
        'SDL',
        'SDL_mixer'
      ],
      'SDL::Mixer::Channels' => [
        'SDL',
        'SDL_mixer'
      ],
      'SDL::Version' => [
        'SDL'
      ],
      'SDLx::Validate' => [
        'SDL'
      ],
      'SDL::Time' => [
        'SDL'
      ],
      'SDLx::Controller::State' => [
        'SDL'
      ],
      'SDL::Event' => [
        'SDL'
      ],
      'SDL::Mixer::Music' => [
        'SDL',
        'SDL_mixer'
      ],
      'SDLx::Controller::Timer' => [
        'SDL'
      ],
      'SDL::RWOps' => [
        'SDL'
      ],
      'SDL::Image' => [
        'SDL',
        'SDL_image'
      ],
      'SDLx::Surface' => [
        'SDL',
        'SDL_gfx'
      ],
      'SDL::GFX::BlitFunc' => [
        'SDL',
        'SDL_gfx'
      ],
      'SDL::AudioSpec' => [
        'SDL'
      ],
      'SDL::Mixer::Groups' => [
        'SDL',
        'SDL_mixer'
      ],
      'SDL::Joystick' => [
        'SDL'
      ],
      'SDLx::Controller::Interface' => [
        'SDL'
      ],
      'SDL::Mixer::MixMusic' => [
        'SDL',
        'SDL_mixer'
      ]
    },
    'libraries' => {
      'SDL_gfx' => {
        'lib' => 'SDL_gfx',
        'define' => 'HAVE_SDL_GFX',
        'header' => 'SDL_gfxPrimitives.h'
      },
      'SDL_ttf' => {
        'header' => 'SDL_ttf.h',
        'define' => 'HAVE_SDL_TTF',
        'lib' => 'SDL_ttf'
      },
      'SDL_mixer' => {
        'define' => 'HAVE_SDL_MIXER',
        'lib' => 'SDL_mixer',
        'header' => 'SDL_mixer.h'
      },
      'tiff' => {
        'header' => 'tiff.h',
        'lib' => 'tiff',
        'define' => 'HAVE_TIFF'
      },
      'SDL_image' => {
        'header' => 'SDL_image.h',
        'define' => 'HAVE_SDL_IMAGE',
        'lib' => 'SDL_image'
      },
      'SDL_Pango' => {
        'define' => 'HAVE_SDL_PANGO',
        'lib' => 'SDL_Pango',
        'header' => 'SDL_Pango.h'
      },
      'jpeg' => {
        'lib' => 'jpeg',
        'define' => 'HAVE_JPEG',
        'header' => 'jpeglib.h'
      },
      'SDL_gfx_imagefilter' => {
        'define' => 'HAVE_SDL_GFX_IMAGEFILTER',
        'lib' => 'SDL_gfx',
        'header' => 'SDL_imageFilter.h'
      },
      'SDL' => {
        'header' => 'SDL.h',
        'lib' => 'SDL',
        'define' => 'HAVE_SDL'
      },
      'smpeg' => {
        'lib' => 'smpeg',
        'define' => 'HAVE_SMPEG',
        'header' => 'smpeg/smpeg.h'
      },
      'GL' => {
        'define' => 'HAVE_GL',
        'lib' => 'GL',
        'header' => [
          'GL/gl.h',
          'GL/glext.h'
        ]
      },
      'SDL_gfx_blitfunc' => {
        'header' => 'SDL_gfxBlitFunc.h',
        'define' => 'HAVE_SDL_GFX_BLITFUNC',
        'lib' => 'SDL_gfx'
      },
      'SDL_gfx_primitives' => {
        'header' => 'SDL_gfxPrimitives.h',
        'define' => 'HAVE_SDL_GFX_PRIMITIVES',
        'lib' => 'SDL_gfx'
      },
      'SDL_gfx_framerate' => {
        'lib' => 'SDL_gfx',
        'define' => 'HAVE_SDL_GFX_FRAMERATE',
        'header' => 'SDL_framerate.h'
      },
      'SDL_gfx_rotozoom' => {
        'header' => 'SDL_rotozoom.h',
        'lib' => 'SDL_gfx',
        'define' => 'HAVE_SDL_GFX_ROTOZOOM'
      },
      'png' => {
        'header' => 'png.h',
        'define' => 'HAVE_PNG',
        'lib' => 'png'
      },
      'GLU' => {
        'header' => 'GL/glu.h',
        'lib' => 'GLU',
        'define' => 'HAVE_GLU'
      }
    },
    'SDL_cfg' => {
      'Version' => {
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'defines' => [
          '-DHAVE_SDL'
        ]
      },
      'Framerate' => {
        'links' => [
          '-lSDL',
          '-lSDL_gfx'
        ],
        'libs' => {
          'SDL_gfx_framerate' => 1,
          'SDL' => 1
        },
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_GFX_FRAMERATE'
        ]
      },
      'Cursor' => {
        'defines' => [
          '-DHAVE_SDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'links' => [
          '-lSDL'
        ]
      },
      'ValidateX' => {
        'defines' => [
          '-DHAVE_SDL'
        ],
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        }
      },
      'GFX' => {
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_GFX_PRIMITIVES'
        ],
        'libs' => {
          'SDL_gfx_primitives' => 1,
          'SDL' => 1
        },
        'links' => [
          '-lSDL',
          '-lSDL_gfx'
        ]
      },
      'MixerChannels' => {
        'links' => [
          '-lSDL',
          '-lSDL_mixer'
        ],
        'libs' => {
          'SDL' => 1,
          'SDL_mixer' => 1
        },
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_MIXER'
        ]
      },
      'MixerGroups' => {
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_MIXER'
        ],
        'libs' => {
          'SDL' => 1,
          'SDL_mixer' => 1
        },
        'links' => [
          '-lSDL',
          '-lSDL_mixer'
        ]
      },
      'Rotozoom' => {
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_GFX_ROTOZOOM'
        ],
        'links' => [
          '-lSDL',
          '-lSDL_gfx'
        ],
        'libs' => {
          'SDL_gfx_rotozoom' => 1,
          'SDL' => 1
        }
      },
      'MixerMusic' => {
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_MIXER'
        ],
        'libs' => {
          'SDL' => 1,
          'SDL_mixer' => 1
        },
        'links' => [
          '-lSDL',
          '-lSDL_mixer'
        ]
      },
      'Video' => {
        'defines' => [
          '-DHAVE_SDL'
        ],
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        }
      },
      'Mouse' => {
        'defines' => [
          '-DHAVE_SDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'links' => [
          '-lSDL'
        ]
      },
      'MixerEffects' => {
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_MIXER'
        ],
        'libs' => {
          'SDL_mixer' => 1,
          'SDL' => 1
        },
        'links' => [
          '-lSDL',
          '-lSDL_mixer'
        ]
      },
      'Color' => {
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'defines' => [
          '-DHAVE_SDL'
        ]
      },
      'Mixer' => {
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_MIXER'
        ],
        'libs' => {
          'SDL' => 1,
          'SDL_mixer' => 1
        },
        'links' => [
          '-lSDL',
          '-lSDL_mixer'
        ]
      },
      'CDTrack' => {
        'defines' => [
          '-DHAVE_SDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'links' => [
          '-lSDL'
        ]
      },
      'CDROM' => {
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'defines' => [
          '-DHAVE_SDL'
        ]
      },
      'TTF_Font' => {
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_TTF'
        ],
        'links' => [
          '-lSDL',
          '-lSDL_ttf'
        ],
        'libs' => {
          'SDL' => 1,
          'SDL_ttf' => 1
        }
      },
      'MixMusic' => {
        'libs' => {
          'SDL' => 1,
          'SDL_mixer' => 1
        },
        'links' => [
          '-lSDL',
          '-lSDL_mixer'
        ],
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_MIXER'
        ]
      },
      'TimerX' => {
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'defines' => [
          '-DHAVE_SDL'
        ]
      },
      'Pango' => {
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_PANGO'
        ],
        'links' => [
          '-lSDL',
          '-lSDL_Pango'
        ],
        'libs' => {
          'SDL' => 1,
          'SDL_Pango' => 1
        }
      },
      'VideoInfo' => {
        'defines' => [
          '-DHAVE_SDL'
        ],
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        }
      },
      'LayerManagerX' => {
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'defines' => [
          '-DHAVE_SDL'
        ]
      },
      'Events' => {
        'defines' => [
          '-DHAVE_SDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'links' => [
          '-lSDL'
        ]
      },
      'AudioSpec' => {
        'defines' => [
          '-DHAVE_SDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'links' => [
          '-lSDL'
        ]
      },
      'PixelFormat' => {
        'defines' => [
          '-DHAVE_SDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'links' => [
          '-lSDL'
        ]
      },
      'Event' => {
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'defines' => [
          '-DHAVE_SDL'
        ]
      },
      'SFont' => {
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_IMAGE'
        ],
        'links' => [
          '-lSDL',
          '-lSDL_image'
        ],
        'libs' => {
          'SDL' => 1,
          'SDL_image' => 1
        }
      },
      'Surface' => {
        'defines' => [
          '-DHAVE_SDL'
        ],
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        }
      },
      'MultiThread' => {
        'defines' => [
          '-DHAVE_SDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'links' => [
          '-lSDL'
        ]
      },
      'Context' => {
        'libs' => {
          'SDL_Pango' => 1,
          'SDL' => 1
        },
        'links' => [
          '-lSDL',
          '-lSDL_Pango'
        ],
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_PANGO'
        ]
      },
      'FPSManager' => {
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_GFX_FRAMERATE'
        ],
        'links' => [
          '-lSDL',
          '-lSDL_gfx'
        ],
        'libs' => {
          'SDL_gfx_framerate' => 1,
          'SDL' => 1
        }
      },
      'SDL' => {
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'defines' => [
          '-DHAVE_SDL'
        ]
      },
      'AudioCVT' => {
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'defines' => [
          '-DHAVE_SDL'
        ]
      },
      'Overlay' => {
        'defines' => [
          '-DHAVE_SDL'
        ],
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        }
      },
      'InterfaceX' => {
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'defines' => [
          '-DHAVE_SDL'
        ]
      },
      'CD' => {
        'libs' => {
          'SDL' => 1
        },
        'links' => [
          '-lSDL'
        ],
        'defines' => [
          '-DHAVE_SDL'
        ]
      },
      'Rect' => {
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'defines' => [
          '-DHAVE_SDL'
        ]
      },
      'BlitFunc' => {
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_GFX_BLITFUNC'
        ],
        'libs' => {
          'SDL' => 1,
          'SDL_gfx_blitfunc' => 1
        },
        'links' => [
          '-lSDL',
          '-lSDL_gfx'
        ]
      },
      'LayerX' => {
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_IMAGE'
        ],
        'links' => [
          '-lSDL',
          '-lSDL_image'
        ],
        'libs' => {
          'SDL_image' => 1,
          'SDL' => 1
        }
      },
      'StateX' => {
        'libs' => {
          'SDL' => 1
        },
        'links' => [
          '-lSDL'
        ],
        'defines' => [
          '-DHAVE_SDL'
        ]
      },
      'MixChunk' => {
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_MIXER'
        ],
        'links' => [
          '-lSDL',
          '-lSDL_mixer'
        ],
        'libs' => {
          'SDL' => 1,
          'SDL_mixer' => 1
        }
      },
      'MixerSamples' => {
        'links' => [
          '-lSDL',
          '-lSDL_mixer'
        ],
        'libs' => {
          'SDL_mixer' => 1,
          'SDL' => 1
        },
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_MIXER'
        ]
      },
      'Time' => {
        'libs' => {
          'SDL' => 1
        },
        'links' => [
          '-lSDL'
        ],
        'defines' => [
          '-DHAVE_SDL'
        ]
      },
      'ImageFilter' => {
        'links' => [
          '-lSDL',
          '-lSDL_gfx'
        ],
        'libs' => {
          'SDL' => 1,
          'SDL_gfx_imagefilter' => 1
        },
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_GFX_IMAGEFILTER'
        ]
      },
      'RWOps' => {
        'libs' => {
          'SDL' => 1
        },
        'links' => [
          '-lSDL'
        ],
        'defines' => [
          '-DHAVE_SDL'
        ]
      },
      'Primitives' => {
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_GFX_PRIMITIVES'
        ],
        'libs' => {
          'SDL_gfx_primitives' => 1,
          'SDL' => 1
        },
        'links' => [
          '-lSDL',
          '-lSDL_gfx'
        ]
      },
      'TTF' => {
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_TTF'
        ],
        'libs' => {
          'SDL' => 1,
          'SDL_ttf' => 1
        },
        'links' => [
          '-lSDL',
          '-lSDL_ttf'
        ]
      },
      'SurfaceX' => {
        'links' => [
          '-lSDL',
          '-lSDL_gfx'
        ],
        'libs' => {
          'SDL_gfx_primitives' => 1,
          'SDL' => 1
        },
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_GFX_PRIMITIVES'
        ]
      },
      'Audio' => {
        'defines' => [
          '-DHAVE_SDL'
        ],
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        }
      },
      'Palette' => {
        'defines' => [
          '-DHAVE_SDL'
        ],
        'libs' => {
          'SDL' => 1
        },
        'links' => [
          '-lSDL'
        ]
      },
      'Joystick' => {
        'defines' => [
          '-DHAVE_SDL'
        ],
        'links' => [
          '-lSDL'
        ],
        'libs' => {
          'SDL' => 1
        }
      },
      'Image' => {
        'libs' => {
          'SDL_image' => 1,
          'SDL' => 1
        },
        'links' => [
          '-lSDL',
          '-lSDL_image'
        ],
        'defines' => [
          '-DHAVE_SDL',
          '-DHAVE_SDL_IMAGE'
        ]
      }
    },
    'subsystems' => {
      'ImageFilter' => {
        'file' => {
          'to' => 'lib/SDL/GFX/ImageFilter.xs',
          'from' => 'src/GFX/ImageFilter.xs'
        },
        'libraries' => [
          'SDL',
          'SDL_gfx_imagefilter'
        ]
      },
      'RWOps' => {
        'libraries' => [
          'SDL'
        ],
        'file' => {
          'to' => 'lib/SDL/RWOps.xs',
          'from' => 'src/Core/objects/RWOps.xs'
        }
      },
      'StateX' => {
        'file' => {
          'to' => 'lib/SDLx/Controller/State.xs',
          'from' => 'src/SDLx/Controller/State.xs'
        },
        'libraries' => [
          'SDL'
        ]
      },
      'MixerSamples' => {
        'libraries' => [
          'SDL',
          'SDL_mixer'
        ],
        'file' => {
          'to' => 'lib/SDL/Mixer/Samples.xs',
          'from' => 'src/Mixer/Samples.xs'
        }
      },
      'MixChunk' => {
        'libraries' => [
          'SDL',
          'SDL_mixer'
        ],
        'file' => {
          'from' => 'src/Mixer/objects/MixChunk.xs',
          'to' => 'lib/SDL/Mixer/MixChunk.xs'
        }
      },
      'Time' => {
        'file' => {
          'from' => 'src/Core/Time.xs',
          'to' => 'lib/SDL/Time.xs'
        },
        'libraries' => [
          'SDL'
        ]
      },
      'Primitives' => {
        'libraries' => [
          'SDL',
          'SDL_gfx_primitives'
        ],
        'file' => {
          'from' => 'src/GFX/Primitives.xs',
          'to' => 'lib/SDL/GFX/Primitives.xs'
        }
      },
      'Palette' => {
        'file' => {
          'to' => 'lib/SDL/Palette.xs',
          'from' => 'src/Core/objects/Palette.xs'
        },
        'libraries' => [
          'SDL'
        ]
      },
      'TTF' => {
        'libraries' => [
          'SDL',
          'SDL_ttf'
        ],
        'file' => {
          'from' => 'src/TTF/TTF.xs',
          'to' => 'lib/SDL/TTF.xs'
        }
      },
      'SurfaceX' => {
        'file' => {
          'to' => 'lib/SDLx/Surface.xs',
          'from' => 'src/SDLx/Surface.xs'
        },
        'libraries' => [
          'SDL',
          'SDL_gfx_primitives'
        ]
      },
      'Audio' => {
        'file' => {
          'from' => 'src/Core/Audio.xs',
          'to' => 'lib/SDL/Audio.xs'
        },
        'libraries' => [
          'SDL'
        ]
      },
      'Image' => {
        'libraries' => [
          'SDL',
          'SDL_image'
        ],
        'file' => {
          'to' => 'lib/SDL/Image.xs',
          'from' => 'src/Image.xs'
        }
      },
      'Joystick' => {
        'libraries' => [
          'SDL'
        ],
        'file' => {
          'to' => 'lib/SDL/Joystick.xs',
          'from' => 'src/Core/Joystick.xs'
        }
      },
      'MultiThread' => {
        'file' => {
          'to' => 'lib/SDL/MultiThread.xs',
          'from' => 'src/Core/MultiThread.xs'
        },
        'libraries' => [
          'SDL'
        ]
      },
      'Surface' => {
        'file' => {
          'to' => 'lib/SDL/Surface.xs',
          'from' => 'src/Core/objects/Surface.xs'
        },
        'libraries' => [
          'SDL'
        ]
      },
      'FPSManager' => {
        'file' => {
          'from' => 'src/GFX/FPSManager.xs',
          'to' => 'lib/SDL/GFX/FPSManager.xs'
        },
        'libraries' => [
          'SDL',
          'SDL_gfx_framerate'
        ]
      },
      'SDL' => {
        'libraries' => [
          'SDL'
        ],
        'file' => {
          'from' => 'src/SDL.xs',
          'to' => 'lib/SDL_perl.xs'
        }
      },
      'AudioCVT' => {
        'file' => {
          'from' => 'src/Core/objects/AudioCVT.xs',
          'to' => 'lib/SDL/AudioCVT.xs'
        },
        'libraries' => [
          'SDL'
        ]
      },
      'Context' => {
        'file' => {
          'from' => 'src/Pango/objects/Context.xs',
          'to' => 'lib/SDL/Pango/Context.xs'
        },
        'libraries' => [
          'SDL',
          'SDL_Pango'
        ]
      },
      'CD' => {
        'libraries' => [
          'SDL'
        ],
        'file' => {
          'from' => 'src/Core/objects/CD.xs',
          'to' => 'lib/SDL/CD.xs'
        }
      },
      'Rect' => {
        'file' => {
          'from' => 'src/Core/objects/Rect.xs',
          'to' => 'lib/SDL/Rect.xs'
        },
        'libraries' => [
          'SDL'
        ]
      },
      'InterfaceX' => {
        'file' => {
          'from' => 'src/SDLx/Controller/Interface.xs',
          'to' => 'lib/SDLx/Controller/Interface.xs'
        },
        'libraries' => [
          'SDL'
        ]
      },
      'Overlay' => {
        'libraries' => [
          'SDL'
        ],
        'file' => {
          'to' => 'lib/SDL/Overlay.xs',
          'from' => 'src/Core/objects/Overlay.xs'
        }
      },
      'BlitFunc' => {
        'file' => {
          'from' => 'src/GFX/BlitFunc.xs',
          'to' => 'lib/SDL/GFX/BlitFunc.xs'
        },
        'libraries' => [
          'SDL',
          'SDL_gfx_blitfunc'
        ]
      },
      'LayerX' => {
        'libraries' => [
          'SDL',
          'SDL_image'
        ],
        'file' => {
          'from' => 'src/SDLx/Layer.xs',
          'to' => 'lib/SDLx/Layer.xs'
        }
      },
      'TimerX' => {
        'libraries' => [
          'SDL'
        ],
        'file' => {
          'from' => 'src/SDLx/Timer.xs',
          'to' => 'lib/SDLx/Controller/Timer.xs'
        }
      },
      'MixMusic' => {
        'file' => {
          'to' => 'lib/SDL/Mixer/MixMusic.xs',
          'from' => 'src/Mixer/objects/MixMusic.xs'
        },
        'libraries' => [
          'SDL',
          'SDL_mixer'
        ]
      },
      'Pango' => {
        'libraries' => [
          'SDL',
          'SDL_Pango'
        ],
        'file' => {
          'from' => 'src/Pango/Pango.xs',
          'to' => 'lib/SDL/Pango.xs'
        }
      },
      'VideoInfo' => {
        'file' => {
          'from' => 'src/Core/objects/VideoInfo.xs',
          'to' => 'lib/SDL/VideoInfo.xs'
        },
        'libraries' => [
          'SDL'
        ]
      },
      'Events' => {
        'libraries' => [
          'SDL'
        ],
        'file' => {
          'from' => 'src/Core/Events.xs',
          'to' => 'lib/SDL/Events.xs'
        }
      },
      'AudioSpec' => {
        'file' => {
          'from' => 'src/Core/objects/AudioSpec.xs',
          'to' => 'lib/SDL/AudioSpec.xs'
        },
        'libraries' => [
          'SDL'
        ]
      },
      'PixelFormat' => {
        'libraries' => [
          'SDL'
        ],
        'file' => {
          'from' => 'src/Core/objects/PixelFormat.xs',
          'to' => 'lib/SDL/PixelFormat.xs'
        }
      },
      'LayerManagerX' => {
        'libraries' => [
          'SDL'
        ],
        'file' => {
          'from' => 'src/SDLx/LayerManager.xs',
          'to' => 'lib/SDLx/LayerManager.xs'
        }
      },
      'Event' => {
        'file' => {
          'to' => 'lib/SDL/Event.xs',
          'from' => 'src/Core/objects/Event.xs'
        },
        'libraries' => [
          'SDL'
        ]
      },
      'SFont' => {
        'file' => {
          'to' => 'lib/SDLx/SFont.xs',
          'from' => 'src/SDLx/SFont.xs'
        },
        'libraries' => [
          'SDL',
          'SDL_image'
        ]
      },
      'Cursor' => {
        'libraries' => [
          'SDL'
        ],
        'file' => {
          'to' => 'lib/SDL/Cursor.xs',
          'from' => 'src/Core/objects/Cursor.xs'
        }
      },
      'ValidateX' => {
        'libraries' => [
          'SDL'
        ],
        'file' => {
          'from' => 'src/SDLx/Validate.xs',
          'to' => 'lib/SDLx/Validate.xs'
        }
      },
      'Version' => {
        'libraries' => [
          'SDL'
        ],
        'file' => {
          'to' => 'lib/SDL/Version.xs',
          'from' => 'src/Core/objects/Version.xs'
        }
      },
      'Framerate' => {
        'libraries' => [
          'SDL',
          'SDL_gfx_framerate'
        ],
        'file' => {
          'from' => 'src/GFX/Framerate.xs',
          'to' => 'lib/SDL/GFX/Framerate.xs'
        }
      },
      'Rotozoom' => {
        'file' => {
          'to' => 'lib/SDL/GFX/Rotozoom.xs',
          'from' => 'src/GFX/Rotozoom.xs'
        },
        'libraries' => [
          'SDL',
          'SDL_gfx_rotozoom'
        ]
      },
      'MixerMusic' => {
        'file' => {
          'from' => 'src/Mixer/Music.xs',
          'to' => 'lib/SDL/Mixer/Music.xs'
        },
        'libraries' => [
          'SDL',
          'SDL_mixer'
        ]
      },
      'GFX' => {
        'libraries' => [
          'SDL',
          'SDL_gfx_primitives'
        ],
        'file' => {
          'from' => 'src/GFX/GFX.xs',
          'to' => 'lib/SDL/GFX.xs'
        }
      },
      'MixerChannels' => {
        'libraries' => [
          'SDL',
          'SDL_mixer'
        ],
        'file' => {
          'from' => 'src/Mixer/Channels.xs',
          'to' => 'lib/SDL/Mixer/Channels.xs'
        }
      },
      'MixerGroups' => {
        'file' => {
          'from' => 'src/Mixer/Groups.xs',
          'to' => 'lib/SDL/Mixer/Groups.xs'
        },
        'libraries' => [
          'SDL',
          'SDL_mixer'
        ]
      },
      'MixerEffects' => {
        'file' => {
          'from' => 'src/Mixer/Effects.xs',
          'to' => 'lib/SDL/Mixer/Effects.xs'
        },
        'libraries' => [
          'SDL',
          'SDL_mixer'
        ]
      },
      'Color' => {
        'file' => {
          'to' => 'lib/SDL/Color.xs',
          'from' => 'src/Core/objects/Color.xs'
        },
        'libraries' => [
          'SDL'
        ]
      },
      'Mouse' => {
        'file' => {
          'from' => 'src/Core/Mouse.xs',
          'to' => 'lib/SDL/Mouse.xs'
        },
        'libraries' => [
          'SDL'
        ]
      },
      'Video' => {
        'file' => {
          'from' => 'src/Core/Video.xs',
          'to' => 'lib/SDL/Video.xs'
        },
        'libraries' => [
          'SDL'
        ]
      },
      'CDROM' => {
        'libraries' => [
          'SDL'
        ],
        'file' => {
          'to' => 'lib/SDL/CDROM.xs',
          'from' => 'src/Core/CDROM.xs'
        }
      },
      'CDTrack' => {
        'libraries' => [
          'SDL'
        ],
        'file' => {
          'from' => 'src/Core/objects/CDTrack.xs',
          'to' => 'lib/SDL/CDTrack.xs'
        }
      },
      'TTF_Font' => {
        'libraries' => [
          'SDL',
          'SDL_ttf'
        ],
        'file' => {
          'from' => 'src/TTF/objects/Font.xs',
          'to' => 'lib/SDL/TTF/Font.xs'
        }
      },
      'Mixer' => {
        'libraries' => [
          'SDL',
          'SDL_mixer'
        ],
        'file' => {
          'from' => 'src/Mixer/Mixer.xs',
          'to' => 'lib/SDL/Mixer.xs'
        }
      }
    }
  },
  {},
  {}
];
$x; }